@@ -1,12 +1,12 @@
 import numpy as np
 import aghasher
-import aghashercore
+import CPFcluster.aghashercore as aghashercore
 import scipy.sparse
 import math
 import multiprocessing as mp
 import itertools
 import pandas as pd
-import utils as utils
+import CPFcluster.utils as utils
 import gc
 from tqdm import tqdm
 
